/* Version and patchlevel for TimeTracker */
#define PATCHLEVEL 98
#define VERSION 1
#define COMMENT "Patch 1"

